Cross platform nagios plugins
=============================

The focus cp-nagios-plugins is to start providing the functionality of many
of the core plugins from the nagios-plugins repository.  This primary purpose
of this is to support these tests on Windows.   The plugins are written
in a way so that they are cross platform where possible.

These cross platform plugins rely on Python to attain that cross platform
ability.  This means that they are more expensive to run than the compiled
programs from the Nagios-plugins repository.


Plugins
=======

A list of the current plugins is available `here <docs/plugins.rst>`_.
